@@ -6,9 +6,8 @@ from AsteriskRealtimeData.domain.pause_reason.pause_reason_created_vo import (
 
 
 class PauseReasonController:
-    def create(self, pause_reason: PauseReasonVo) -> PauseReasonCreatedVo:
-        pause_reason_parameter = PauseReasonVo(**pause_reason)
-        return PauseReasonService().create_pause_reason(pause_reason_parameter)
+    def create(self, pause_reason_vo: PauseReasonVo) -> PauseReasonCreatedVo:
+        return PauseReasonService().create_pause_reason(pause_reason_vo)
 
     def list(self) -> list[dict]:
         pause_reasons = PauseReasonService().list_pause_reason()
@@ -19,8 +18,8 @@ class PauseReasonController:
 
         return result
 
-    def get_by_criteria(self, search_criteria: str) -> dict:
-        return PauseReasonService().get_pause_reason(search_criteria).as_dict()
+    def get_by_pause_code(self, pause_code: str) -> dict:
+        return PauseReasonService().get_pause_reason(pause_code).as_dict()
 
-    def delete_by_criteria(self, search_criteria: str) -> dict:
-        return PauseReasonService().delete_pause_reason(search_criteria)
+    def delete_by_pause_code(self, pause_code: str) -> dict:
+        return PauseReasonService().delete_pause_reason(pause_code)
